### BEGIN LICENSE
# Copyright (C) 2012 <De Gaetano Andrea> <dega1999@yahoo.com>
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

from gi.repository import Gtk # pylint: disable=E0611

from protoborsa_lib.helpers import get_builder

import gettext
from gettext import gettext as _
gettext.textdomain('protoborsa')

from protoborsa_lib import personaldata

class SearchstockDialog(Gtk.Dialog):
    __gtype_name__ = "SearchstockDialog"

    def __new__(cls):
        """Special static method that's automatically called by Python when 
        constructing a new instance of this class.
        
        Returns a fully instantiated SearchstockDialog object.
        """
        builder = get_builder('SearchstockDialog')
        new_object = builder.get_object('searchstock_dialog')
        new_object.finish_initializing(builder)
        return new_object

    def finish_initializing(self, builder):
        """Called when we're finished initializing.

        finish_initalizing should be called after parsing the ui definition
        and creating a SearchstockDialog object with it in order to
        finish initializing the start of the new SearchstockDialog
        instance.
        """
        # Get a reference to the builder and set up the signals.
        self.builder = builder
        self.ui = builder.get_ui(self)
        self.symbolsListStore = builder.get_object('liststore1');
        self.symbolsListStore.append(['Loading','...']);
        self.symbolsList = personaldata.getAllStockSymbols();
        self.symbolsListStore.clear();
        self.appendOnSimbolsList(self.symbolsList);
        self.gtkSymbolsList = builder.get_object('symbolsList');
    def appendOnSimbolsList(self,toUpdate):
        for elem in toUpdate:        
            self.symbolsListStore.append(elem);

    def filterOnCompany(self,textSearch):
        results = [];
        for elem in self.symbolsList:
            if str(elem[1].lower()).startswith(textSearch.lower()):
                results.append(elem);
        return results;
	
    def selectedStock(self):
        model, tree_iter =  self.gtkSymbolsList.get_selection().get_selected()
        if(tree_iter == None):
            return None;
        symbol = model.get_value(tree_iter, 0);
        company = model.get_value(tree_iter, 1);
        return (symbol,company);
    
    def on_searchCompany_changed(self,widget, data=None):
        searchTxt = widget.get_text();
        if(len(searchTxt) > 3):
            newData = self.filterOnCompany(searchTxt);
            self.symbolsListStore.clear();
            self.appendOnSimbolsList(newData);
        if(len(searchTxt) == 0 ):
            self.symbolsListStore.clear();
            self.appendOnSimbolsList(self.symbolsList);

    def on_btn_ok_clicked(self, widget, data=None):
        """The user has elected to save the changes.

        Called before the dialog returns Gtk.ResponseType.OK from run().
        """
        pass

    def on_btn_cancel_clicked(self, widget, data=None):
        """The user has elected cancel changes.

        Called before the dialog returns Gtk.ResponseType.CANCEL for run()
        """
        pass


if __name__ == "__main__":
    dialog = SearchstockDialog()
    dialog.show()
    Gtk.main()
